<?php

namespace Drupal\vertical_tabs_states_test\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DefaultForm.
 *
 * @package Drupal\vertical_tabs_states_test\Form
 */
class DefaultForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'default_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // First set of vertical tabs for testing visible state.
    $form['toggle_visible'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Toggle visibility'),
      '#default_value' => FALSE,
    );
    $form['vertical_tabs1'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-details1',
      '#states' => array(
        'visible' => array(
          'input[name=toggle_visible]' => array('checked' => FALSE),
        ),
      ),
    );
    $form['details1'] = array(
      '#type' => 'details',
      '#title' => $this->t('details1'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs1',
    );
    $form['details1']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 1'),
    );
    $form['details2'] = array(
      '#type' => 'details',
      '#title' => $this->t('details2'),
      '#group' => 'vertical_tabs1',
    );
    $form['details2']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 2'),
    );

    // Second set of vertical tabs for testing enabled state with value
    $form['toggle_enabled'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Toggle enabled'),
      '#default_value' => 'enabled',
      '#options' => array(
        'enabled' => $this->t('Enabled'),
        'disabled' => $this->t('Disabled'),
      )
    );
    $form['vertical_tabs2'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-details3',
      '#states' => array(
        'enabled' => array(
          'input[name=toggle_enabled]' => array('value' => 'enabled'),
        ),
      ),
    );
    $form['details3'] = array(
      '#type' => 'details',
      '#title' => $this->t('details3'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs2',
    );
    $form['details3']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 3'),
    );
    $form['details3']['sample2'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Testing 3 again'),
    );
    $form['details4'] = array(
      '#type' => 'details',
      '#title' => $this->t('details4'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs2',
    );
    $form['details4']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 4'),
    );
    $form['details4']['sample2'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Testing 4 again'),
    );

    // Third set of vertical tabs for testing optional state with empty
    $form['toggle_optional'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Toggle optional'),
      '#default_value' => NULL,
      '#description' => $this->t('Enter any value to set the vertical tab\'s fields to be optional'),
    );
    $form['vertical_tabs3'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-details6',
      '#states' => array(
        'optional' => array(
          'input[name=toggle_optional]' => array('empty' => FALSE),
        ),
      ),
    );
    $form['details5'] = array(
      '#type' => 'details',
      '#title' => $this->t('details5'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs3',
      '#required' => TRUE,
    );
    $form['details5']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 5'),
    );
    $form['details5']['sample2'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Testing 5 again'),
    );
    $form['details6'] = array(
      '#type' => 'details',
      '#title' => $this->t('details6'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs3',
      '#required' => TRUE,
    );
    $form['details6']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 6'),
    );
    $form['details6']['sample2'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Testing 6 again'),
    );

    // Fourth set of vertical tabs for testing nested vertical stabs
    $form['vertical_tabs4'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-details7',
    );
    $form['details7'] = array(
      '#type' => 'details',
      '#title' => $this->t('details7'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs4',
      '#required' => TRUE,
    );
    $form['details7']['toggle_visible2'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Toggle visibility on nested tab'),
      '#default_value' => FALSE,
    );
    $form['details7']['vertical_tabs5'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-details9',
      '#states' => array(
        'visible' => array(
          'input[name=toggle_visible2]' => array('checked' => TRUE),
        ),
      ),
    );
    $form['details9'] = array(
      '#type' => 'details',
      '#title' => $this->t('details9'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs5',
      '#required' => TRUE,
    );
    $form['details9']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 9'),
    );
     $form['details10'] = array(
      '#type' => 'details',
      '#title' => $this->t('details10'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs5',
      '#required' => TRUE,
    );
    $form['details10']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 10'),
    );
    $form['details8'] = array(
      '#type' => 'details',
      '#title' => $this->t('details8'),
      '#open' => TRUE,
      '#group' => 'vertical_tabs4',
      '#required' => TRUE,
    );
    $form['details8']['sample'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Testing 8'),
    );

    return $form;
  }

 /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Display result.
    foreach ($form_state->getValues() as $key => $value) {
        drupal_set_message($key . ': ' . $value);
    }

  }

}
